@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 import datetime
-from typing import Any, Iterator, Union
+from typing import Any, Iterator, Union, List, Dict
 from urllib.parse import quote_plus
 
 from hiro_graph_client.clientlib import AuthenticatedAPIHandler, AbstractTokenApiHandler
@@ -31,7 +31,8 @@ class HiroGraph(AuthenticatedAPIHandler):
               limit=-1,
               offset=0,
               order: str = None,
-              meta: bool = None) -> dict:
+              meta: bool = None,
+              count: bool = None) -> dict:
         """
         https://core.arago.co/help/specs/?url=definitions/graph.yaml#/[Query]_Search/post_query_vertices
 
@@ -41,17 +42,25 @@ class HiroGraph(AuthenticatedAPIHandler):
         :param offset: offset where to start returning entries
         :param order: order by a field asc|desc, e.g. ogit/name desc
         :param meta: List detailed metainformations in result payload
+        :param count: Just return the number of found items. Result payload is like
+               {"items":[&lt;number of items found as int&gt;]}.
         :return: Result payload
         """
         url = self.endpoint + '/query/vertices'
-        data = {"query": str(query),
-                "limit": limit,
-                "fields": (quote_plus(fields.replace(" ", ""), safe="/,") if fields else ""),
-                "count": False,
-                "listMeta": self._bool_to_external_str(meta),
-                "offset": offset}
-        if order is not None:
+
+        data = {"query": str(query)}
+        if fields:
+            data['fields'] = quote_plus(fields.replace(" ", ""), safe="/,")
+        if limit is not None:
+            data['limit'] = limit
+        if offset:
+            data['offset'] = offset
+        if order:
             data['order'] = order
+        if meta is not None:
+            data['listMeta'] = meta
+        if count is not None:
+            data['count'] = count
         return self.post(url, data)
 
     def query_gremlin(self,
@@ -71,11 +80,15 @@ class HiroGraph(AuthenticatedAPIHandler):
         :return: Result payload
         """
         url = self.endpoint + '/query/gremlin'
+
         data = {"query": str(query),
-                "root": root,
-                "fields": (quote_plus(fields.replace(" ", ""), safe="/,") if fields else ""),
-                "includeDeleted": self._bool_to_external_str(include_deleted),
-                "listMeta": self._bool_to_external_str(meta)}
+                "root": root}
+        if fields:
+            data['fields'] = quote_plus(fields.replace(" ", ""), safe="/,")
+        if include_deleted is not None:
+            data['include_deleted'] = include_deleted
+        if meta is not None:
+            data['listMeta'] = meta
         return self.post(url, data)
 
     def create_node(self, data: dict, obj_type: str, return_id=False) -> Union[dict, str]:
@@ -225,7 +238,7 @@ class HiroGraph(AuthenticatedAPIHandler):
                        limit: int = None,
                        with_ids: str = None,
                        order: str = "asc",
-                       aggregate: str = None) -> dict:
+                       aggregate: str = None) -> Union[List, Dict]:
         """
         https://core.arago.co/help/specs/?url=definitions/graph.yaml#/[Query]_Timeseries/get__id__values
 
@@ -237,7 +250,7 @@ class HiroGraph(AuthenticatedAPIHandler):
         :param with_ids: list of ids to aggregate in result
         :param limit: limit of entries to return
         :param include_deleted: allow to get if ogit/_is-deleted=true
-        :return: The result payload
+        :return: The result payload. Either a list of dict or a dict with an error message.
         """
         query = {
             "from": starttime,
@@ -253,20 +266,20 @@ class HiroGraph(AuthenticatedAPIHandler):
         res = self.get(url)
         if 'error' in res:
             return res
-        timeseries = res['items']
+        timeseries: list = res['items']
         return timeseries
 
     def get_timeseries_history(self,
                                node_id: str,
                                timestamp: str = None,
-                               include_deleted: bool = None) -> dict:
+                               include_deleted: bool = None) -> Union[List, Dict]:
         """
         https://core.arago.co/help/specs/?url=definitions/graph.yaml#/[Query]_Timeseries/get__id__values_history
 
         :param node_id: ogit/_id of the node containing timeseries
         :param timestamp: timestamp in ms
         :param include_deleted: allow to get if ogit/_is-deleted=true
-        :return: The result payload
+        :return: The result payload. Either a list of dict or a dict with an error message.
         """
         query = {
             "include_deleted": include_deleted,
@@ -277,7 +290,7 @@ class HiroGraph(AuthenticatedAPIHandler):
         res = self.get(url)
         if 'error' in res:
             return res
-        timeseries = res['items']
+        timeseries: list = res['items']
         return timeseries
 
     def query_timeseries(self,
@@ -285,7 +298,7 @@ class HiroGraph(AuthenticatedAPIHandler):
                          endtime: str = None,
                          limit: int = None,
                          order: str = "asc",
-                         aggregate: str = None) -> dict:
+                         aggregate: str = None) -> Union[List, Dict]:
         """
         Run a query against the graph and return agragated timeseries values for timeseries vertices matching
         query result. query: Entities with matching ogit/_type:ogit/Timeseries
@@ -297,7 +310,7 @@ class HiroGraph(AuthenticatedAPIHandler):
         :param aggregate: aggregate numeric values for multiple timeseries ids with same timestamp: avg|min|max|sum|none
         :param order: order by a timestamp asc|desc|none. Default is "asc" here.
         :param limit: limit of entries to return
-        :return: The result payload
+        :return: The result payload. Either a list of dict or a dict with an error message.
         """
         query = {
             "from": starttime,
@@ -311,7 +324,7 @@ class HiroGraph(AuthenticatedAPIHandler):
         res = self.get(url)
         if 'error' in res:
             return res
-        timeseries = res['items']
+        timeseries: list = res['items']
         return timeseries
 
     def post_timeseries(self,
